@@ -195,8 +195,8 @@ HTSEXT_API int catch_url(T_SOC soc,char* url,char* method,char* data) {
       socinput(soc,line,1000);
       if (strnotempty(line)) {
         if (sscanf(line,"%s %s %s",method,url,protocol) == 3) {
-          char url_adr[HTS_URLMAXSIZE*2];
-          char url_fil[HTS_URLMAXSIZE*2];
+          char BIGSTK url_adr[HTS_URLMAXSIZE*2];
+          char BIGSTK url_fil[HTS_URLMAXSIZE*2];
           // mthode en majuscule
           int i,r=0;
           url_adr[0]=url_fil[0]='\0';
@@ -208,7 +208,7 @@ HTSEXT_API int catch_url(T_SOC soc,char* url,char* method,char* data) {
           // adresse du lien
           if (ident_url_absolute(url,url_adr,url_fil)>=0) {
             // Traitement des en-ttes
-            char loc[HTS_URLMAXSIZE*2];
+            char BIGSTK loc[HTS_URLMAXSIZE*2];
             htsblk blkretour;
             memset(&blkretour, 0, sizeof(htsblk));    // effacer
             blkretour.location=loc;    // si non nul, contiendra l'adresse vritable en cas de moved xx
