@@ -254,14 +254,15 @@ int main(int argc, char **argv) {
   httrack.maxcache=1048576*32;  // a peu prs 32Mo en cache max -- OPTION NON PARAMETRABLE POUR L'INSTANT --
   //httrack.maxcache_anticipate=256;  // maximum de liens  anticiper
   httrack.maxtime=-1;        // temps max en secondes
-  httrack.maxrate=-1;        // pas de taux maxi
-  httrack.maxconn=10.0;      // nombre connexions/s
+  httrack.maxrate=25000;     // default max rate
+  httrack.maxconn=5.0;       // nombre connexions/s
   httrack.waittime=-1;       // wait until.. hh*3600+mm*60+ss
   //
   httrack.exec=argv[0];
   httrack.is_update=0;      // not an update (yet)
   httrack.dir_topindex=0;   // do not built top index (yet)
   //
+  httrack.bypass_limits=0;  // enforce limits by default
   httrack.state.stop=0;     // stopper
   httrack.state.exit_xh=0;  // abort
   //
@@ -1230,6 +1231,7 @@ int main(int argc, char **argv) {
             case 'u': httrack.urlhack=1; if (*(com+1)=='0') { httrack.urlhack=0; com++; } break;   // url hack
             case 'v': httrack.verbosedisplay=2; if (isdigit((unsigned char)*(com+1))) { sscanf(com+1,"%d",&httrack.verbosedisplay); while(isdigit((unsigned char)*(com+1))) com++; } break;
             case 'i': httrack.dir_topindex = 1; if (*(com+1)=='0') { httrack.dir_topindex=0; com++; } break;
+            case '!': httrack.bypass_limits = 1; if (*(com+1)=='0') { httrack.bypass_limits=0; com++; } break;
 
             // preserve: no footer, original links
             case 'p':
@@ -2265,6 +2267,32 @@ int main(int argc, char **argv) {
     
     io_flush;
 
+    /* Enforce limits to avoid bandwith abuse. The bypass_limits should only be used by administrators and experts. */
+    if (!httrack.bypass_limits) {
+      if (httrack.maxsoc <= 0 || httrack.maxsoc > 4) {
+        httrack.maxsoc = 4;
+        if (httrack.log != NULL) {
+          fspc(httrack.log,"warning"); fprintf(httrack.log,"* security warning: maximum number of simultaneous connections limited to %d to avoid server overload"LF, (int)httrack.maxsoc);
+        }
+      }
+      if (httrack.maxrate <= 0 || httrack.maxrate > 100000) {
+        httrack.maxrate = 100000;
+        if (httrack.log != NULL) {
+          fspc(httrack.log,"warning"); fprintf(httrack.log,"* security warning: maximum bandwidth limited to %d to avoid server overload"LF, (int)httrack.maxrate);
+        }
+      }
+      if (httrack.maxconn <= 0 || httrack.maxconn > 5.0) {
+        httrack.maxconn = 5.0;
+        if (httrack.log != NULL) {
+          fspc(httrack.log,"warning"); fprintf(httrack.log,"* security warning: maximum number of connections per second limited to %f to avoid server overload"LF, (float)httrack.maxconn);
+        }
+      }
+    } else {
+      if (httrack.log != NULL) {
+        fspc(httrack.log,"warning"); fprintf(httrack.log,"* security warning: !!! BYPASSING SECURITY LIMITS - MONITOR THIS SESSION WITH EXTREME CARE !!!"LF);
+      }
+    }
+
   /* Info for wrappers */
   if ( (httrack.debug>0) && (httrack.log!=NULL) ) {
     fspc(httrack.log,"info"); fprintf(httrack.log,"engine: init"LF);
