@@ -542,6 +542,11 @@ void help(char* app,int more) {
   infomsg(" #Z  generate transfer rate statictics every minutes");
   infomsg(" #!  execute a shell command (-#! \"echo hello\")");
   infomsg("");
+  infomsg("Dangerous options: (do NOT use unless you exactly know what you are doing)");
+  infomsg(" %!  bypass built-in security limits aimed to avoid bandwith abuses (bandwidth, simultaneous connections)");
+  infomsg("     IMPORTANT NOTE: DANGEROUS OPTION, ONLY SUITABLE FOR EXPERTS");
+  infomsg("                     USE IT WITH EXTREME CARE");
+  infomsg("");
   infomsg("Command-line specific options:");
   infomsg("  V execute system command after each files ($0 is the filename: -V \"rm \\$0\")");
   infomsg(" %U run the engine with another id when called as root (-%U smith)");
