@@ -158,6 +158,7 @@ static void addCallback(htscallbacks* chain, void* moduleHandle, htscallbacksfnc
   chain->moduleHandle = moduleHandle;
 }
 
+void clearCallbacks(htscallbacks* chain_);
 void clearCallbacks(htscallbacks* chain_) {
   htscallbacks* chain;
   chain = chain_;
@@ -188,9 +189,9 @@ void clearCallbacks(htscallbacks* chain_) {
   chain_->next = NULL;    // Empty
 }
 
-/* NOTE: handled NOT closed */
+void* getFunctionPtr(httrackp* opt, char* file_, char* fncname);
 void* getFunctionPtr(httrackp* opt, char* file_, char* fncname) {
-  char file[1024];
+  char BIGSTK file[1024];
   void* handle;
   void* userfunction = NULL;
   strcpybuff(file, file_);
@@ -210,7 +211,7 @@ void* getFunctionPtr(httrackp* opt, char* file_, char* fncname) {
   if (handle) {
     /* Thanks to Lars Clausen for the "wrapper-init" patch */
     /* If given arguments, call "<wrappername>_init" */
-    char tmpName[1024];
+    char BIGSTK tmpName[1024];
     char *comma;
     if ((comma = strchr(fncname, ',')) != NULL) {   /* empty arg */
       *comma++ = '\0';
@@ -396,6 +397,7 @@ static void htspe_log(htsmoduleStruct* str, char* msg) {
   }
 }
 
+HTSEXT_API const char* hts_is_available(void);
 HTSEXT_API const char* hts_is_available(void) {
   return WHAT_is_available;
 }
