@@ -37,7 +37,7 @@ Please visit our Website: http://www.httrack.com
 /* ------------------------------------------------------------ */
 
 
-typedef struct {
+typedef struct htsmoduleStructExtended {
   /* Main object */
   htsblk* r_;
 
