@@ -39,7 +39,7 @@ Please visit our Website: http://www.httrack.com
 #ifndef HTS_STRINGS_DEFSTATIC
 #define HTS_STRINGS_DEFSTATIC 
 
-typedef struct {
+typedef struct String {
   char* buff;
   int len;
   int capa;
